Documentation
¶
Index ¶
Constants ¶
const ( CharDash rune = '-' CharWhitespace = ' ' CharTab = '\t' CharCommentStarter = '#' CharNewline = '\n' CharColon = ':' CharPipe = '|' CharComma = ',' CharGreaterThan = '>' CharQuestionMark = '?' CharExclamationMark = '!' CharAmpersand = '&' CharAsterisk = '*' CharSingleQuote = '\'' CharDoubleQuote = '"' CharPeriod = '.' CharOpeningSquareBracket = '[' CharClosingSquareBracket = ']' CharOpeningCurlyBrace = '{' CharClosingCurlyBrace = '}' )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Location ¶
type Location struct {
// contains filtered or unexported fields
}
Location represent the Location of the Token within the document
type Type ¶
type Type int8
const ( TypeUnknown Type = iota // TypeData could refer to a key or value of any data type TypeData TypeColon TypeDocumentStart TypeDocumentEnd // TypeIndentation indicates Type is an indentation. // An indentation is zero or more spaces preceding a newline rune TypeIndentation TypeNewline TypePipe TypeComma TypeGreaterThan TypeQuestionMark TypeExclamationMark TypeAmpersand TypeAsterisk TypeComment TypeOpeningSquareBracket TypeClosingSquareBracket TypeOpeningCurlyBrace TypeClosingCurlyBrace )
Click to show internal directories.
Click to hide internal directories.